Raw Numeric XBRL — Calcbench API Client documentation

# Raw Numeric XBRL

All of the XBRL tagged numbers as reported in the XBRL documents submitted by the filers

class calcbench.raw_numeric_XBRL.Operator(value)

  An enumeration.

  Contains = 10
  Equals = 1
  NotEquals = 21

class calcbench.raw_numeric_XBRL.RawDataClause(*args, **kwargs)
  operator: calcbench.raw_numeric_XBRL.Operator
  parameter: str
  value: str

calcbench.raw_numeric_XBRL.raw_XBRL(company_identifiers=[], entire_universe=False, clauses=[])

  As-reported data.

  Parameters

    - company_identifiers (`Sequence`[`Union`[`str`, `int`]]) – list of tickers or CIK codes

    - entire_universe (`bool`) – Search all companies

    - clauses (`Sequence`[`RawDataClause`]) – See the parameters that can be passed @ https://www.calcbench.com/api/rawdataxbrlpoints

  Usage:

        >>> clauses = [
        >>>     {"value": "Revenues", "parameter": "XBRLtag", "operator": 10},
        >>>     {"value": "Y", "parameter": "fiscalPeriod", "operator": 1},
        >>>     {"value": "2018", "parameter": "fiscalYear", "operator": 1}
        >>> ]
        >>> cb.raw_xbrl(company_identifiers=['mmm'], clauses=clauses)

  Return type

    `DataFrame`

calcbench.raw_numeric_XBRL.raw_xbrl_raw(company_identifiers=[], entire_universe=False, clauses=[])

  Data as reported in the XBRL documents

  Parameters

    - company_identifiers (`Sequence`[`Union`[`str`, `int`]]) – list of tickers or CIK codes

    - entire_universe (`bool`) – Search all companies

    - clauses (`Sequence`[`RawDataClause`]) – See the parameters that can be passed @ https://www.calcbench.com/api/rawdataxbrlpoints

  Usage:

        >>> clauses = [
        >>>     {"value": "Revenues", "parameter": "XBRLtag", "operator": 10},
        >>>     {"value": "Y", "parameter": "fiscalPeriod", "operator": 1},
        >>>     {"value": "2018", "parameter": "fiscalYear", "operator": 1}
        >>> ]
        >>> cb.raw_xbrl_raw(company_identifiers=['mmm'], clauses=clauses)

  Return type

    `Sequence`[`Mapping`[`str`, `object`]]